Why it matters

Triton makes kernel authoring accessible. Understanding shapes optimization.

Advertisement

The architecture

@triton.jit decorator on kernel functions.

Grid launch.

Block-level primitives.

Triton stackTriton DSLPython-likeJIT compilePTXLaunch on GPUgrid + blocksFlashAttention v2/v3, Inductor generated, custom kernels all use Triton
Triton.
Advertisement

How it works end to end

@triton.jit: JIT-compile kernel.

tl.load / tl.store: memory ops.

tl.dot: matmul.

Autotune configs.